## ioos_pkg_skeleton

[![Build Status](https://travis-ci.com/ioos/ioos-python-package-skeleton.svg?branch=master)](https://travis-ci.com/ioos/ioos-python-package-skeleton)

Quick description

### Documentation and code

URLs for the docs and code.

### Installation

For `conda` users you can

```shell
conda install --channel conda-forge ioos_pkg_skeleton
```

or, if you are a `pip` users

```shell
pip install ioos_pkg_skeleton
```

### Example

```python
from ioos_pkg_skeleton import ioos_pkg_skeleton


ioos_pkg_skeleton.meaning_of_life_url()
```


## Get in touch

Report bugs, suggest features or view the source code on [GitHub](https://github.com/ioos/ioos_pkg_skeleton/issues).


## License and copyright

ioos_pkg_skeleton is licensed under BSD 3-Clause "New" or "Revised" License (BSD-3-Clause).

Development occurs on GitHub at <https://github.com/ioos/ioos_pkg_skeleton>.
